PaymobSdkPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- PaymobSdkPlatform
- Implementers
Constructors
- PaymobSdkPlatform()
- Constructs a PaymobSdkPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startPayment(
PaymobParams params) → Future< PaymobCheckoutStatus?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PaymobSdkPlatform
-
The default instance of PaymobSdkPlatform to use.
getter/setter pair