PaymobParams class

Constructors

PaymobParams({required String publicKey, required String clientSecret, String? appName, Color? buttonBackgroundColor, Color? buttonTextColor, bool? saveCardDefault, bool? showSaveCard})
const

Properties

appName String?
final
buttonBackgroundColor Color?
final
buttonTextColor Color?
final
clientSecret String
final
hashCode int
The hash code for this object.
no setterinherited
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveCardDefault bool?
final
showSaveCard bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited